#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
JSON验证引擎
提供完整的JSON数据格式验证、示例模板和错误处理
"""

import json
import logging
from typing import Dict, List, Any, Optional, Union, Tuple
from dataclasses import dataclass, field
from datetime import datetime
import re
from pathlib import Path

logger = logging.getLogger(__name__)

# ==================== 数据结构定义 ====================

@dataclass
class ValidationResult:
    """验证结果"""
    is_valid: bool
    errors: List[str] = field(default_factory=list)
    warnings: List[str] = field(default_factory=list)
    suggestions: List[str] = field(default_factory=list)
    corrected_data: Optional[Dict[str, Any]] = None

@dataclass
class JSONSchema:
    """JSON模式定义"""
    schema_id: str
    schema_name: str
    description: str
    schema: Dict[str, Any]
    examples: List[Dict[str, Any]] = field(default_factory=list)
    common_errors: List[Dict[str, Any]] = field(default_factory=list)

@dataclass
class ValidationRule:
    """验证规则"""
    rule_id: str
    rule_name: str
    description: str
    validator: callable
    error_message: str
    fix_suggestion: Optional[str] = None

# ==================== JSON验证引擎 ====================

class JSONValidationEngine:
    """JSON验证引擎 - 提供完整的JSON数据格式验证和示例"""
    
    def __init__(self):
        self.schemas: Dict[str, JSONSchema] = {}
        self.validation_rules: Dict[str, ValidationRule] = {}
        
        # 初始化预定义模式
        self._initialize_predefined_schemas()
        self._initialize_validation_rules()
        
        logger.info("JSON验证引擎初始化完成")
    
    def _initialize_predefined_schemas(self):
        """初始化预定义的JSON模式"""
        
        # 1. 创建文档模式
        create_document_schema = JSONSchema(
            schema_id="create_document",
            schema_name="创建文档",
            description="创建Word文档的JSON数据格式",
            schema={
                "type": "object",
                "properties": {
                    "filename": {
                        "type": "string",
                        "description": "文档文件名",
                        "pattern": r"^[^<>:\"/\\|?*]+\.docx$",
                        "minLength": 1,
                        "maxLength": 255
                    },
                    "title": {
                        "type": "string",
                        "description": "文档标题（可选）",
                        "maxLength": 200
                    },
                    "page_settings": {
                        "type": "object",
                        "description": "页面设置（可选）",
                        "properties": {
                            "margins": {
                                "type": "object",
                                "properties": {
                                    "top": {"type": "number", "minimum": 0.5, "maximum": 5.0},
                                    "bottom": {"type": "number", "minimum": 0.5, "maximum": 5.0},
                                    "left": {"type": "number", "minimum": 0.5, "maximum": 5.0},
                                    "right": {"type": "number", "minimum": 0.5, "maximum": 5.0}
                                }
                            },
                            "orientation": {
                                "type": "string",
                                "enum": ["portrait", "landscape"],
                                "description": "页面方向"
                            },
                            "size": {
                                "type": "string",
                                "enum": ["A4", "A3", "Letter", "Legal"],
                                "description": "页面大小"
                            }
                        }
                    }
                },
                "required": ["filename"],
                "additionalProperties": False
            },
            examples=[
                {
                    "description": "基本文档创建",
                    "data": {
                        "filename": "新文档.docx"
                    }
                },
                {
                    "description": "带标题的文档创建",
                    "data": {
                        "filename": "报告.docx",
                        "title": "月度销售报告"
                    }
                },
                {
                    "description": "完整配置的文档创建",
                    "data": {
                        "filename": "正式报告.docx",
                        "title": "2024年度总结报告",
                        "page_settings": {
                            "margins": {
                                "top": 2.54,
                                "bottom": 2.54,
                                "left": 3.18,
                                "right": 3.18
                            },
                            "orientation": "portrait",
                            "size": "A4"
                        }
                    }
                }
            ],
            common_errors=[
                {
                    "error": "缺少filename参数",
                    "example": {"title": "报告标题"},
                    "fix": "添加必需的filename参数",
                    "corrected": {"filename": "报告.docx", "title": "报告标题"}
                },
                {
                    "error": "文件名格式不正确",
                    "example": {"filename": "报告.doc"},
                    "fix": "使用.docx扩展名",
                    "corrected": {"filename": "报告.docx"}
                },
                {
                    "error": "页面边距值超出范围",
                    "example": {"filename": "报告.docx", "page_settings": {"margins": {"top": 10}}},
                    "fix": "边距值应在0.5-5.0之间",
                    "corrected": {"filename": "报告.docx", "page_settings": {"margins": {"top": 2.54}}}
                }
            ]
        )
        
        self.schemas["create_document"] = create_document_schema
        
        # 2. 添加段落模式
        add_paragraph_schema = JSONSchema(
            schema_id="add_paragraph",
            schema_name="添加段落",
            description="向文档添加段落的JSON数据格式",
            schema={
                "type": "object",
                "properties": {
                    "filename": {
                        "type": "string",
                        "description": "目标文档文件名",
                        "pattern": r"^[^<>:\"/\\|?*]+\.docx$"
                    },
                    "text": {
                        "type": "string",
                        "description": "段落文本内容",
                        "minLength": 1,
                        "maxLength": 10000
                    },
                    "style": {
                        "type": "string",
                        "description": "段落样式（可选）",
                        "enum": ["normal", "heading1", "heading2", "heading3", "emphasis", "quote"]
                    },
                    "alignment": {
                        "type": "string",
                        "description": "文本对齐方式（可选）",
                        "enum": ["left", "center", "right", "justify"]
                    },
                    "position": {
                        "type": "string",
                        "description": "插入位置（可选）",
                        "enum": ["beginning", "end", "after_heading"]
                    }
                },
                "required": ["filename", "text"],
                "additionalProperties": False
            },
            examples=[
                {
                    "description": "基本段落添加",
                    "data": {
                        "filename": "文档.docx",
                        "text": "这是一个示例段落。"
                    }
                },
                {
                    "description": "带样式的段落",
                    "data": {
                        "filename": "文档.docx",
                        "text": "重要内容",
                        "style": "emphasis",
                        "alignment": "center"
                    }
                },
                {
                    "description": "标题段落",
                    "data": {
                        "filename": "文档.docx",
                        "text": "第一章 引言",
                        "style": "heading1",
                        "alignment": "left"
                    }
                }
            ],
            common_errors=[
                {
                    "error": "文本内容为空",
                    "example": {"filename": "文档.docx", "text": ""},
                    "fix": "提供有效的文本内容",
                    "corrected": {"filename": "文档.docx", "text": "段落内容"}
                },
                {
                    "error": "文本内容过长",
                    "example": {"filename": "文档.docx", "text": "很长的文本..."},
                    "fix": "文本长度不应超过10000字符",
                    "corrected": {"filename": "文档.docx", "text": "适当长度的文本"}
                }
            ]
        )
        
        self.schemas["add_paragraph"] = add_paragraph_schema
        
        # 3. 添加图片模式
        add_picture_schema = JSONSchema(
            schema_id="add_picture",
            schema_name="添加图片",
            description="向文档添加图片的JSON数据格式",
            schema={
                "type": "object",
                "properties": {
                    "filename": {
                        "type": "string",
                        "description": "目标文档文件名",
                        "pattern": r"^[^<>:\"/\\|?*]+\.docx$"
                    },
                    "image_path": {
                        "type": "string",
                        "description": "图片文件路径",
                        "pattern": r"^.+\.(jpg|jpeg|png|gif|bmp|tiff)$",
                        "minLength": 1
                    },
                    "width": {
                        "type": "number",
                        "description": "图片宽度（像素，可选）",
                        "minimum": 50,
                        "maximum": 2000
                    },
                    "height": {
                        "type": "number",
                        "description": "图片高度（像素，可选）",
                        "minimum": 50,
                        "maximum": 2000
                    },
                    "alignment": {
                        "type": "string",
                        "description": "图片对齐方式（可选）",
                        "enum": ["left", "center", "right"]
                    },
                    "caption": {
                        "type": "string",
                        "description": "图片标题（可选）",
                        "maxLength": 200
                    }
                },
                "required": ["filename", "image_path"],
                "additionalProperties": False
            },
            examples=[
                {
                    "description": "基本图片添加",
                    "data": {
                        "filename": "文档.docx",
                        "image_path": "images/photo.jpg"
                    }
                },
                {
                    "description": "带尺寸控制的图片",
                    "data": {
                        "filename": "文档.docx",
                        "image_path": "images/photo.jpg",
                        "width": 400,
                        "height": 300
                    }
                },
                {
                    "description": "带标题的图片",
                    "data": {
                        "filename": "文档.docx",
                        "image_path": "images/chart.png",
                        "width": 500,
                        "alignment": "center",
                        "caption": "图1：销售趋势图"
                    }
                }
            ],
            common_errors=[
                {
                    "error": "图片格式不支持",
                    "example": {"filename": "文档.docx", "image_path": "images/photo.pdf"},
                    "fix": "使用支持的图片格式（jpg, png, gif, bmp, tiff）",
                    "corrected": {"filename": "文档.docx", "image_path": "images/photo.jpg"}
                },
                {
                    "error": "图片尺寸过大",
                    "example": {"filename": "文档.docx", "image_path": "images/photo.jpg", "width": 5000},
                    "fix": "图片尺寸应在50-2000像素之间",
                    "corrected": {"filename": "文档.docx", "image_path": "images/photo.jpg", "width": 500}
                }
            ]
        )
        
        self.schemas["add_picture"] = add_picture_schema
        
        # 4. 添加表格模式
        add_table_schema = JSONSchema(
            schema_id="add_table",
            schema_name="添加表格",
            description="向文档添加表格的JSON数据格式",
            schema={
                "type": "object",
                "properties": {
                    "filename": {
                        "type": "string",
                        "description": "目标文档文件名",
                        "pattern": r"^[^<>:\"/\\|?*]+\.docx$"
                    },
                    "rows": {
                        "type": "integer",
                        "description": "表格行数",
                        "minimum": 1,
                        "maximum": 100
                    },
                    "cols": {
                        "type": "integer",
                        "description": "表格列数",
                        "minimum": 1,
                        "maximum": 20
                    },
                    "data": {
                        "type": "array",
                        "description": "表格数据（可选）",
                        "items": {
                            "type": "array",
                            "items": {"type": "string"}
                        }
                    },
                    "has_header": {
                        "type": "boolean",
                        "description": "是否有表头"
                    },
                    "table_style": {
                        "type": "object",
                        "description": "表格样式（可选）",
                        "properties": {
                            "border_style": {
                                "type": "string",
                                "enum": ["solid", "dashed", "dotted", "none"]
                            },
                            "header_color": {
                                "type": "string",
                                "pattern": r"^#[0-9A-Fa-f]{6}$"
                            },
                            "alternating_rows": {
                                "type": "boolean"
                            }
                        }
                    }
                },
                "required": ["filename", "rows", "cols"],
                "additionalProperties": False
            },
            examples=[
                {
                    "description": "基本表格创建",
                    "data": {
                        "filename": "文档.docx",
                        "rows": 3,
                        "cols": 3
                    }
                },
                {
                    "description": "带数据的表格",
                    "data": {
                        "filename": "文档.docx",
                        "rows": 3,
                        "cols": 3,
                        "data": [
                            ["姓名", "部门", "职位"],
                            ["张三", "技术部", "工程师"],
                            ["李四", "销售部", "经理"]
                        ],
                        "has_header": True
                    }
                },
                {
                    "description": "带样式的表格",
                    "data": {
                        "filename": "文档.docx",
                        "rows": 4,
                        "cols": 4,
                        "has_header": True,
                        "table_style": {
                            "border_style": "solid",
                            "header_color": "#4472C4",
                            "alternating_rows": True
                        }
                    }
                }
            ],
            common_errors=[
                {
                    "error": "行数或列数为0",
                    "example": {"filename": "文档.docx", "rows": 0, "cols": 3},
                    "fix": "行数和列数必须大于0",
                    "corrected": {"filename": "文档.docx", "rows": 1, "cols": 3}
                },
                {
                    "error": "数据行数与指定行数不匹配",
                    "example": {"filename": "文档.docx", "rows": 3, "cols": 2, "data": [["A", "B"]]},
                    "fix": "数据行数应与指定的行数一致",
                    "corrected": {"filename": "文档.docx", "rows": 3, "cols": 2, "data": [["A", "B"], ["C", "D"], ["E", "F"]]}
                }
            ]
        )
        
        self.schemas["add_table"] = add_table_schema
        
        # 5. 工作流执行模式
        workflow_execution_schema = JSONSchema(
            schema_id="workflow_execution",
            schema_name="工作流执行",
            description="执行工作流的JSON数据格式",
            schema={
                "type": "object",
                "properties": {
                    "workflow_id": {
                        "type": "string",
                        "description": "工作流ID",
                        "enum": ["create_document", "edit_document", "add_image_to_document", "create_table", "apply_template"]
                    },
                    "parameters": {
                        "type": "object",
                        "description": "工作流参数",
                        "additionalProperties": True
                    },
                    "execution_options": {
                        "type": "object",
                        "description": "执行选项（可选）",
                        "properties": {
                            "timeout": {
                                "type": "integer",
                                "minimum": 30,
                                "maximum": 3600
                            },
                            "retry_count": {
                                "type": "integer",
                                "minimum": 0,
                                "maximum": 5
                            },
                            "continue_on_error": {
                                "type": "boolean"
                            }
                        }
                    }
                },
                "required": ["workflow_id", "parameters"],
                "additionalProperties": False
            },
            examples=[
                {
                    "description": "基本工作流执行",
                    "data": {
                        "workflow_id": "create_document",
                        "parameters": {
                            "filename": "新文档.docx"
                        }
                    }
                },
                {
                    "description": "带执行选项的工作流",
                    "data": {
                        "workflow_id": "add_image_to_document",
                        "parameters": {
                            "filename": "文档.docx",
                            "image_path": "images/photo.jpg"
                        },
                        "execution_options": {
                            "timeout": 300,
                            "retry_count": 2,
                            "continue_on_error": False
                        }
                    }
                }
            ],
            common_errors=[
                {
                    "error": "工作流ID不存在",
                    "example": {"workflow_id": "invalid_workflow", "parameters": {}},
                    "fix": "使用有效的工作流ID",
                    "corrected": {"workflow_id": "create_document", "parameters": {"filename": "文档.docx"}}
                }
            ]
        )
        
        self.schemas["workflow_execution"] = workflow_execution_schema
        
        # 6. OSS上传模式
        oss_upload_schema = JSONSchema(
            schema_id="oss_upload",
            schema_name="OSS上传",
            description="上传文档到OSS云存储的JSON数据格式",
            schema={
                "type": "object",
                "properties": {
                    "custom_filename": {
                        "type": "string",
                        "description": "OSS上的自定义文件名（可选）",
                        "pattern": r"^[^<>:\"/\\|?*]+\.docx$",
                        "maxLength": 255
                    },
                    "document_path": {
                        "type": "string",
                        "description": "要上传的文档路径（可选，默认使用当前文档）",
                        "pattern": r"^.+\.docx$"
                    },
                    "auto_upload": {
                        "type": "boolean",
                        "description": "是否自动上传（默认true）",
                        "default": True
                    }
                },
                "additionalProperties": False,
                "anyOf": [
                    {"required": ["auto_upload"]},
                    {"required": ["custom_filename"]},
                    {"required": ["document_path"]}
                ]
            },
            examples=[
                {
                    "description": "基本OSS上传",
                    "data": {
                        "auto_upload": True
                    }
                },
                {
                    "description": "带自定义文件名的上传",
                    "data": {
                        "custom_filename": "月度报告_202401.docx",
                        "auto_upload": True
                    }
                },
                {
                    "description": "上传指定文档",
                    "data": {
                        "document_path": "documents/报告.docx",
                        "custom_filename": "最终报告.docx",
                        "auto_upload": True
                    }
                }
            ],
            common_errors=[
                {
                    "error": "文件名格式不正确",
                    "example": {"custom_filename": "报告.doc"},
                    "fix": "使用.docx扩展名",
                    "corrected": {"custom_filename": "报告.docx"}
                },
                {
                    "error": "文档路径不存在",
                    "example": {"document_path": "不存在的路径.docx"},
                    "fix": "确保文档路径正确且文件存在",
                    "corrected": {"document_path": "documents/报告.docx"}
                }
            ]
        )
        
        self.schemas["oss_upload"] = oss_upload_schema
    
    def _initialize_validation_rules(self):
        """初始化验证规则"""
        
        # 文件名验证规则
        self.validation_rules["filename_format"] = ValidationRule(
            rule_id="filename_format",
            rule_name="文件名格式验证",
            description="验证文件名格式是否正确",
            validator=self._validate_filename_format,
            error_message="文件名格式不正确",
            fix_suggestion="文件名应不包含特殊字符，并以.docx结尾"
        )
        
        # 图片路径验证规则
        self.validation_rules["image_path"] = ValidationRule(
            rule_id="image_path",
            rule_name="图片路径验证",
            description="验证图片路径和格式",
            validator=self._validate_image_path,
            error_message="图片路径或格式不正确",
            fix_suggestion="使用支持的图片格式（jpg, png, gif, bmp, tiff）"
        )
        
        # 数值范围验证规则
        self.validation_rules["numeric_range"] = ValidationRule(
            rule_id="numeric_range",
            rule_name="数值范围验证",
            description="验证数值是否在有效范围内",
            validator=self._validate_numeric_range,
            error_message="数值超出有效范围",
            fix_suggestion="调整数值到有效范围内"
        )
    
    def validate_json(self, schema_id: str, data: Dict[str, Any]) -> ValidationResult:
        """验证JSON数据"""
        if schema_id not in self.schemas:
            return ValidationResult(
                is_valid=False,
                errors=[f"模式不存在: {schema_id}"]
            )
        
        schema = self.schemas[schema_id]
        result = ValidationResult(is_valid=True)
        
        # 基本结构验证
        if not isinstance(data, dict):
            result.is_valid = False
            result.errors.append("数据必须是JSON对象")
            return result
        
        # 必需字段验证
        for required_field in schema.schema.get("required", []):
            if required_field not in data:
                result.is_valid = False
                result.errors.append(f"缺少必需字段: {required_field}")
        
        # 字段类型验证
        properties = schema.schema.get("properties", {})
        for field_name, field_value in data.items():
            if field_name in properties:
                field_schema = properties[field_name]
                field_result = self._validate_field(field_name, field_value, field_schema)
                if not field_result["is_valid"]:
                    result.is_valid = False
                    result.errors.extend(field_result["errors"])
                result.warnings.extend(field_result["warnings"])
        
        # 自定义规则验证（仅对相关模式应用）
        if schema_id in ["create_document", "add_picture"]:
            for rule_id, rule in self.validation_rules.items():
                if not rule.validator(data):
                    result.is_valid = False
                    result.errors.append(rule.error_message)
                    if rule.fix_suggestion:
                        result.suggestions.append(rule.fix_suggestion)
        
        # 如果验证失败，尝试提供修正建议
        if not result.is_valid:
            result.corrected_data = self._suggest_corrections(schema_id, data)
        
        return result
    
    def _validate_field(self, field_name: str, field_value: Any, field_schema: Dict[str, Any]) -> Dict[str, Any]:
        """验证单个字段"""
        result = {"is_valid": True, "errors": [], "warnings": []}
        
        # 类型验证
        expected_type = field_schema.get("type")
        if expected_type and not self._check_type(field_value, expected_type):
            result["is_valid"] = False
            result["errors"].append(f"字段 {field_name} 类型错误，期望 {expected_type}，实际 {type(field_value).__name__}")
        
        # 字符串验证
        if expected_type == "string":
            string_result = self._validate_string(field_value, field_schema)
            if not string_result["is_valid"]:
                result["is_valid"] = False
                result["errors"].extend(string_result["errors"])
            result["warnings"].extend(string_result["warnings"])
        
        # 数值验证
        elif expected_type in ["integer", "number"]:
            numeric_result = self._validate_numeric(field_value, field_schema)
            if not numeric_result["is_valid"]:
                result["is_valid"] = False
                result["errors"].extend(numeric_result["errors"])
            result["warnings"].extend(numeric_result["warnings"])
        
        # 枚举验证
        if "enum" in field_schema:
            if field_value not in field_schema["enum"]:
                result["is_valid"] = False
                result["errors"].append(f"字段 {field_name} 值不在允许的枚举值中: {field_schema['enum']}")
        
        return result
    
    def _check_type(self, value: Any, expected_type: str) -> bool:
        """检查值类型"""
        type_mapping = {
            "string": str,
            "integer": int,
            "number": (int, float),
            "boolean": bool,
            "array": list,
            "object": dict
        }
        
        expected_python_type = type_mapping.get(expected_type)
        if expected_python_type:
            return isinstance(value, expected_python_type)
        
        return True
    
    def _validate_string(self, value: Any, schema: Dict[str, Any]) -> Dict[str, Any]:
        """验证字符串"""
        result = {"is_valid": True, "errors": [], "warnings": []}
        
        if not isinstance(value, str):
            result["is_valid"] = False
            result["errors"].append("值必须是字符串")
            return result
        
        # 长度验证
        if "minLength" in schema and len(value) < schema["minLength"]:
            result["is_valid"] = False
            result["errors"].append(f"字符串长度不能少于 {schema['minLength']} 个字符")
        
        if "maxLength" in schema and len(value) > schema["maxLength"]:
            result["is_valid"] = False
            result["errors"].append(f"字符串长度不能超过 {schema['maxLength']} 个字符")
        
        # 模式验证
        if "pattern" in schema:
            if not re.match(schema["pattern"], value):
                result["is_valid"] = False
                result["errors"].append(f"字符串格式不符合要求: {schema['pattern']}")
        
        return result
    
    def _validate_numeric(self, value: Any, schema: Dict[str, Any]) -> Dict[str, Any]:
        """验证数值"""
        result = {"is_valid": True, "errors": [], "warnings": []}
        
        if not isinstance(value, (int, float)):
            result["is_valid"] = False
            result["errors"].append("值必须是数值")
            return result
        
        # 范围验证
        if "minimum" in schema and value < schema["minimum"]:
            result["is_valid"] = False
            result["errors"].append(f"数值不能小于 {schema['minimum']}")
        
        if "maximum" in schema and value > schema["maximum"]:
            result["is_valid"] = False
            result["errors"].append(f"数值不能大于 {schema['maximum']}")
        
        return result
    
    def _validate_filename_format(self, data: Dict[str, Any]) -> bool:
        """验证文件名格式"""
        filename = data.get("filename", "")
        if not filename:
            return False
        
        # 检查是否以.docx结尾
        if not filename.endswith(".docx"):
            return False
        
        # 检查是否包含非法字符
        illegal_chars = r'[<>:"/\\|?*]'
        if re.search(illegal_chars, filename):
            return False
        
        return True
    
    def _validate_image_path(self, data: Dict[str, Any]) -> bool:
        """验证图片路径"""
        image_path = data.get("image_path", "")
        if not image_path:
            return False
        
        # 检查文件扩展名
        supported_extensions = [".jpg", ".jpeg", ".png", ".gif", ".bmp", ".tiff"]
        if not any(image_path.lower().endswith(ext) for ext in supported_extensions):
            return False
        
        return True
    
    def _validate_numeric_range(self, data: Dict[str, Any]) -> bool:
        """验证数值范围"""
        # 这里可以添加特定的数值范围验证逻辑
        return True
    
    def _suggest_corrections(self, schema_id: str, data: Dict[str, Any]) -> Dict[str, Any]:
        """建议修正"""
        corrected_data = data.copy()
        schema = self.schemas[schema_id]
        
        # 基于常见错误进行修正
        common_errors = schema.common_errors
        for error_info in common_errors:
            # 这里可以实现自动修正逻辑
            pass
        
        return corrected_data
    
    def get_schema(self, schema_id: str) -> Optional[JSONSchema]:
        """获取模式"""
        return self.schemas.get(schema_id)
    
    def get_schema_examples(self, schema_id: str) -> List[Dict[str, Any]]:
        """获取模式示例"""
        schema = self.schemas.get(schema_id)
        if schema:
            return schema.examples
        return []
    
    def get_common_errors(self, schema_id: str) -> List[Dict[str, Any]]:
        """获取常见错误"""
        schema = self.schemas.get(schema_id)
        if schema:
            return schema.common_errors
        return []
    
    def generate_example_json(self, schema_id: str, example_index: int = 0) -> Optional[Dict[str, Any]]:
        """生成示例JSON"""
        examples = self.get_schema_examples(schema_id)
        if examples and 0 <= example_index < len(examples):
            return examples[example_index]["data"]
        return None
    
    def format_validation_result(self, result: ValidationResult) -> str:
        """格式化验证结果"""
        output = []
        
        if result.is_valid:
            output.append("✅ JSON数据验证通过")
        else:
            output.append("❌ JSON数据验证失败")
        
        if result.errors:
            output.append("\n错误信息:")
            for error in result.errors:
                output.append(f"  • {error}")
        
        if result.warnings:
            output.append("\n警告信息:")
            for warning in result.warnings:
                output.append(f"  ⚠️ {warning}")
        
        if result.suggestions:
            output.append("\n建议:")
            for suggestion in result.suggestions:
                output.append(f"  💡 {suggestion}")
        
        if result.corrected_data:
            output.append("\n修正后的数据:")
            output.append(json.dumps(result.corrected_data, ensure_ascii=False, indent=2))
        
        return "\n".join(output)
    
    def create_custom_schema(self, schema_id: str, schema_definition: Dict[str, Any]) -> bool:
        """创建自定义模式"""
        try:
            schema = JSONSchema(
                schema_id=schema_id,
                schema_name=schema_definition.get("name", schema_id),
                description=schema_definition.get("description", ""),
                schema=schema_definition.get("schema", {}),
                examples=schema_definition.get("examples", []),
                common_errors=schema_definition.get("common_errors", [])
            )
            
            self.schemas[schema_id] = schema
            logger.info(f"创建自定义模式: {schema_id}")
            return True
            
        except Exception as e:
            logger.error(f"创建自定义模式失败: {e}")
            return False



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Enhanced DOCX MCP Core Module
增强版DOCX MCP核心模块

提供完整的Word文档处理能力，包括：
- 文档生命周期管理
- 内容编辑和格式化
- 表格操作
- 图片处理
- 字体管理
- 状态持久化
"""

from .enhanced_docx_processor import EnhancedDocxProcessor
from .state_manager import StateManager
from .enhanced_state_manager import EnhancedStateManager
from .image_processor import ImageProcessor
from .font_processor import FontProcessor
from .oss_processor import OSSProcessor
from .workflow_engine import WorkflowEngine
from .smart_suggestion_engine import SmartSuggestionEngine
from .ai_guidance_enhancer import AIGuidanceEnhancer
from .json_validation_engine import JSONValidationEngine
from .ai_interface import AISmartInterface
from .models import (
    DocumentPatch,
    TableOperation,
    TableOperationType,
    CellAlignment,
    BorderStyle,
    CellFormat,
    TableFormat,
)

__version__ = "2.0.0"
__author__ = "Enhanced DOCX MCP Team"
__email__ = "support@docx-mcp.com"
__description__ = "增强版DOCX MCP处理器 - 完整的Word文档处理工具"

__all__ = [
    "EnhancedDocxProcessor",
    "StateManager",
    "EnhancedStateManager", 
    "ImageProcessor",
    "FontProcessor",
    "OSSProcessor",
    "WorkflowEngine",
    "SmartSuggestionEngine",
    "AIGuidanceEnhancer",
    "JSONValidationEngine",
    "AISmartInterface",
    "DocumentPatch",
    "TableOperation",
    "TableOperationType",
    "CellAlignment",
    "BorderStyle",
    "CellFormat",
    "TableFormat",
]

# 版本信息
VERSION_INFO = {
    "version": __version__,
    "author": __author__,
    "email": __email__,
    "description": __description__,
    "features": [
        "文档生命周期管理",
        "内容编辑和格式化", 
        "表格操作",
        "图片处理",
        "字体管理",
        "状态持久化",
        "MCP协议支持",
        "工作流引擎",
        "智能建议系统",
        "AI指导增强",
        "JSON数据验证",
        "OSS云存储集成",
        "异步处理",
        "错误处理",
        "日志记录"
    ]
}

def get_version_info():
    """获取版本信息"""
    return VERSION_INFO

def print_version_info():
    """打印版本信息"""
    print(f"Enhanced DOCX MCP v{__version__}")
    print(f"Author: {__author__}")
    print(f"Email: {__email__}")
    print(f"Description: {__description__}")
    print("\nFeatures:")
    for feature in VERSION_INFO["features"]:
        print(f"  - {feature}")



import docx
from typing import List, Dict, Any, Union
from io import BytesIO
from docx.document import Document
from docx.table import _Cell, Table
from docx.shared import Inches, Pt, RGBColor
from docx.enum.table import WD_TABLE_ALIGNMENT
from docx.enum.text import WD_PARAGRAPH_ALIGNMENT
from docx.oxml.shared import OxmlElement, qn
from docx.oxml.ns import nsdecls
from docx.oxml import parse_xml
from .models import DocumentPatch, TableOperation, TableOperationType, CellAlignment, BorderStyle

class DocxProcessor:
    """
    负责处理DOCX文件的核心类。
    功能包括：解析文档结构、为元素生成ID、提取内容与格式、以及应用修改。
    所有操作现在都在内存中进行。
    """

    @staticmethod
    def extract_structure_with_ids(file_stream: BytesIO) -> Dict[str, Any]:
        """
        从内存中的文件流解析DOCX文件，提取其结构，并为每个可编辑元素生成唯一ID。

        :param file_stream: 包含.docx文件内容的BytesIO流。
        :return: 一个代表文档结构的字典。
        """
        document = docx.Document(file_stream)
        structure = {"elements": []}
        element_counter = 0

        # 遍历文档的所有顶级元素（段落和表格）
        for element in document.element.body:
            if element.tag.endswith('p'):  # 如果是段落
                p = docx.text.paragraph.Paragraph(element, document)
                paragraph_id = f"p_{element_counter}"
                structure["elements"].append({
                    "id": paragraph_id,
                    "type": "paragraph",
                    "text": p.text,
                    "style": p.style.name,
                })
                element_counter += 1
            elif element.tag.endswith('tbl'):  # 如果是表格
                table = docx.table.Table(element, document)
                table_id = f"tbl_{element_counter}"
                table_data = {
                    "id": table_id,
                    "type": "table",
                    "rows": [],
                    "row_count": len(table.rows),
                    "column_count": len(table.columns) if table.rows else 0,
                    "style": table.style.name if table.style else None
                }
                for i, row in enumerate(table.rows):
                    row_data = {"cells": []}
                    for j, cell in enumerate(row.cells):
                        cell_id = f"{table_id}_r{i}c{j}"
                        row_data["cells"].append({
                            "id": cell_id,
                            "text": cell.text,
                        })
                    table_data["rows"].append(row_data)
                structure["elements"].append(table_data)
                element_counter += 1
        
        return structure

    @staticmethod
    def apply_patches(original_stream: BytesIO, new_stream: BytesIO, patches: List[DocumentPatch]):
        """
        将一系列修改（补丁）应用到内存中的原始DOCX文件流，并将结果写入新的流。

        :param original_stream: 包含原始.docx文件内容的BytesIO流。
        :param new_stream: 用于写入修改后文件内容的BytesIO流。
        :param patches: 一个包含修改指令的列表。
        """
        document = docx.Document(original_stream)
        patches_dict = {p.element_id: p.new_content for p in patches}
        table_operations = [p for p in patches if p.table_operation is not None]

        # 首先处理表格操作（这些操作可能会改变表格结构）
        for patch in table_operations:
            DocxProcessor._apply_table_operation(document, patch.table_operation)

        element_counter = 0
        
        # 然后处理常规的内容修改
        for element in document.element.body:
            if element.tag.endswith('p'):
                current_id = f"p_{element_counter}"
                if current_id in patches_dict:
                    p = docx.text.paragraph.Paragraph(element, document)
                    DocxProcessor._replace_paragraph_text(p, patches_dict[current_id])
                element_counter += 1
            elif element.tag.endswith('tbl'):
                table = docx.table.Table(element, document)
                table_id = f"tbl_{element_counter}"
                for i, row in enumerate(table.rows):
                    for j, cell in enumerate(row.cells):
                        cell_id = f"{table_id}_r{i}c{j}"
                        if cell_id in patches_dict:
                            # 清空单元格并填充新内容
                            cell.text = str(patches_dict[cell_id])
                element_counter += 1

        document.save(new_stream)

    @staticmethod
    def _replace_paragraph_text(p: docx.text.paragraph.Paragraph, new_text: str):
        """
        替换段落的文本，同时尽量保留原始格式。
        
        该方法采用以下策略来保留格式：
        1. 如果段落只有一个run，直接替换文本内容，完全保留格式
        2. 如果段落有多个runs，尝试保留格式分布
        3. 如果新文本较短，使用第一个run的格式
        4. 如果新文本较长，按比例分配格式

        :param p: 要修改的段落对象。
        :param new_text: 新的文本内容。
        """
        if not p.runs:
            # 如果段落没有runs，创建一个新的run
            p.add_run(new_text)
            return
        
        # 保存原始runs的格式信息
        original_runs_info = []
        original_text = ""
        
        for run in p.runs:
            run_info = {
                'text': run.text,
                'bold': run.bold,
                'italic': run.italic,
                'underline': run.underline,
                'font_name': run.font.name,
                'font_size': run.font.size,
                'font_color': None,
                'style': None
            }
            
            # 保存字体颜色（如果有）
            if run.font.color.rgb:
                run_info['font_color'] = run.font.color.rgb
            
            original_runs_info.append(run_info)
            original_text += run.text
        
        # 清空现有的runs
        for run in p.runs[:]:
            r = run._r
            r.getparent().remove(r)
        
        # 策略1: 如果原段落只有一个run，直接替换并保留所有格式
        if len(original_runs_info) == 1:
            new_run = p.add_run(new_text)
            DocxProcessor._apply_run_formatting(new_run, original_runs_info[0])
            return
        
        # 策略2: 如果新文本为空，不添加任何内容
        if not new_text.strip():
            return
        
        # 策略3: 如果新文本很短或原文本很短，使用第一个run的格式
        if len(new_text) <= 50 or len(original_text) <= 10:
            new_run = p.add_run(new_text)
            DocxProcessor._apply_run_formatting(new_run, original_runs_info[0])
            return
        
        # 策略4: 尝试按比例分配格式
        DocxProcessor._distribute_formatting_proportionally(p, new_text, original_runs_info, original_text)

    @staticmethod
    def _apply_run_formatting(run, format_info: Dict[str, Any]):
        """
        将格式信息应用到run对象上。
        
        :param run: docx run对象
        :param format_info: 包含格式信息的字典
        """
        try:
            if format_info.get('bold') is not None:
                run.bold = format_info['bold']
            if format_info.get('italic') is not None:
                run.italic = format_info['italic']
            if format_info.get('underline') is not None:
                run.underline = format_info['underline']
            if format_info.get('font_name'):
                run.font.name = format_info['font_name']
            if format_info.get('font_size'):
                run.font.size = format_info['font_size']
            if format_info.get('font_color'):
                run.font.color.rgb = format_info['font_color']
        except Exception:
            # 如果应用格式失败，忽略错误继续执行
            pass

    @staticmethod
    def _distribute_formatting_proportionally(p, new_text: str, original_runs_info: List[Dict], original_text: str):
        """
        按比例分配格式到新文本中。
        
        :param p: 段落对象
        :param new_text: 新文本
        :param original_runs_info: 原始runs的格式信息
        :param original_text: 原始文本
        """
        if not original_text:
            # 如果原文本为空，使用第一个run的格式
            new_run = p.add_run(new_text)
            if original_runs_info:
                DocxProcessor._apply_run_formatting(new_run, original_runs_info[0])
            return
        
        # 计算每个原始run在文本中的位置比例
        current_pos = 0
        run_positions = []
        
        for run_info in original_runs_info:
            run_text = run_info['text']
            start_ratio = current_pos / len(original_text) if len(original_text) > 0 else 0
            end_ratio = (current_pos + len(run_text)) / len(original_text) if len(original_text) > 0 else 1
            
            run_positions.append({
                'start_ratio': start_ratio,
                'end_ratio': end_ratio,
                'format_info': run_info
            })
            current_pos += len(run_text)
        
        # 根据比例将新文本分段并应用相应格式
        new_text_len = len(new_text)
        last_end = 0
        
        for i, pos_info in enumerate(run_positions):
            start_pos = int(pos_info['start_ratio'] * new_text_len)
            end_pos = int(pos_info['end_ratio'] * new_text_len)
            
            # 确保不会超出边界
            start_pos = max(start_pos, last_end)
            end_pos = min(end_pos, new_text_len)
            
            # 如果是最后一个run，确保包含所有剩余文本
            if i == len(run_positions) - 1:
                end_pos = new_text_len
            
            if start_pos < end_pos:
                segment_text = new_text[start_pos:end_pos]
                if segment_text:  # 只有当片段不为空时才创建run
                    new_run = p.add_run(segment_text)
                    DocxProcessor._apply_run_formatting(new_run, pos_info['format_info'])
                    last_end = end_pos
        
        # 如果还有剩余文本，使用最后一个run的格式
        if last_end < new_text_len:
            remaining_text = new_text[last_end:]
            if remaining_text:
                new_run = p.add_run(remaining_text)
                if original_runs_info:
                    DocxProcessor._apply_run_formatting(new_run, original_runs_info[-1])

    @staticmethod
    def _apply_table_operation(document: Document, operation: TableOperation):
        """
        应用表格操作到文档中。

        :param document: docx文档对象
        :param operation: 表格操作指令
        """
        try:
            # 找到目标表格
            table = DocxProcessor._find_table_by_id(document, operation.table_id)
            if table is None:
                raise ValueError(f"找不到表格: {operation.table_id}")

            # 根据操作类型执行相应操作
            if operation.operation_type == TableOperationType.ADD_ROW:
                DocxProcessor._add_table_row(table, operation.row_index, operation.cell_data)
            elif operation.operation_type == TableOperationType.ADD_COLUMN:
                DocxProcessor._add_table_column(table, operation.column_index, operation.cell_data)
            elif operation.operation_type == TableOperationType.DELETE_ROW:
                DocxProcessor._delete_table_row(table, operation.row_index)
            elif operation.operation_type == TableOperationType.DELETE_COLUMN:
                DocxProcessor._delete_table_column(table, operation.column_index)
            elif operation.operation_type == TableOperationType.FORMAT_TABLE:
                DocxProcessor._format_table(table, operation.table_format)
            elif operation.operation_type == TableOperationType.FORMAT_CELL:
                DocxProcessor._format_cell(table, operation.cell_id, operation.cell_format)
            elif operation.operation_type == TableOperationType.MODIFY_CELL:
                DocxProcessor._modify_cell_content(table, operation.cell_id, operation.new_content)
                
        except Exception as e:
            # 记录错误并抛出异常以便调试
            error_msg = f"表格操作失败: {operation.operation_type}, 错误: {str(e)}"
            print(error_msg)
            raise Exception(error_msg)

    @staticmethod
    def _find_table_by_id(document: Document, table_id: str) -> Table:
        """
        根据表格ID查找表格对象。

        :param document: docx文档对象
        :param table_id: 表格ID（如 "tbl_2"）
        :return: 表格对象或None
        """
        try:
            # 从table_id中提取元素索引（包括段落和表格的总计数）
            element_index = int(table_id.split('_')[1])
            
            # 遍历文档元素，计数所有元素（段落和表格）
            element_counter = 0
            for element in document.element.body:
                if element_counter == element_index:
                    if element.tag.endswith('tbl'):
                        return docx.table.Table(element, document)
                    else:
                        return None  # 索引指向的不是表格
                element_counter += 1
            return None
        except (ValueError, IndexError):
            return None

    @staticmethod
    def _add_table_row(table: Table, row_index: int = None, cell_data: List[str] = None):
        """
        向表格添加新行。

        :param table: 表格对象
        :param row_index: 插入位置（None表示在末尾添加）
        :param cell_data: 新行的单元格数据列表
        """
        if row_index is None:
            row_index = len(table.rows)
        
        # 添加新行
        if row_index is None or row_index >= len(table.rows):
            # 在末尾添加
            new_row = table.add_row()
            # 填充数据
            if cell_data:
                for i, data in enumerate(cell_data):
                    if i < len(new_row.cells):
                        new_row.cells[i].text = str(data)
        else:
            # 在指定位置插入（这个逻辑比较复杂，暂时先实现末尾添加）
            new_row = table.add_row()
            # 填充数据
            if cell_data:
                for i, data in enumerate(cell_data):
                    if i < len(new_row.cells):
                        new_row.cells[i].text = str(data)

    @staticmethod
    def _add_table_column(table: Table, column_index: int = None, cell_data: List[str] = None):
        """
        向表格添加新列。

        :param table: 表格对象
        :param column_index: 插入位置（None表示在末尾添加）
        :param cell_data: 新列的单元格数据列表
        """
        if column_index is None:
            column_index = len(table.columns)
        
        # 为每一行添加新单元格
        for row_idx, row in enumerate(table.rows):
            # 创建新单元格
            new_cell_element = OxmlElement('w:tc')
            
            # 如果有模板单元格，复制其属性
            if len(row.cells) > 0:
                template_cell = row.cells[0]._tc
                for child in template_cell:
                    if child.tag.endswith('tcPr'):
                        new_cell_element.append(child)
                        break
            
            # 添加空段落
            p_element = OxmlElement('w:p')
            new_cell_element.append(p_element)
            
            # 插入到指定位置
            if column_index >= len(row.cells):
                row._tr.append(new_cell_element)
            else:
                row._tr.insert(column_index, new_cell_element)
            
            # 填充数据
            if cell_data and row_idx < len(cell_data):
                new_cell = row.cells[column_index]
                new_cell.text = str(cell_data[row_idx])

    @staticmethod
    def _delete_table_row(table: Table, row_index: int):
        """
        删除表格行。

        :param table: 表格对象
        :param row_index: 要删除的行索引
        """
        if 0 <= row_index < len(table.rows):
            row_element = table.rows[row_index]._tr
            row_element.getparent().remove(row_element)

    @staticmethod
    def _delete_table_column(table: Table, column_index: int):
        """
        删除表格列。

        :param table: 表格对象
        :param column_index: 要删除的列索引
        """
        for row in table.rows:
            if 0 <= column_index < len(row.cells):
                cell_element = row.cells[column_index]._tc
                cell_element.getparent().remove(cell_element)

    @staticmethod
    def _format_table(table: Table, table_format):
        """
        格式化表格样式。

        :param table: 表格对象
        :param table_format: 表格格式配置
        """
        if not table_format:
            return
        
        try:
            # 设置表格宽度
            if table_format.width:
                if table_format.width.endswith('%'):
                    # 百分比宽度
                    width_pct = int(table_format.width.rstrip('%'))
                    table.autofit = False
                    # 这里需要更复杂的XML操作来设置百分比宽度
                
            # 设置列宽
            if table_format.column_widths:
                for i, width_str in enumerate(table_format.column_widths):
                    if i < len(table.columns):
                        try:
                            if width_str.endswith('cm'):
                                width_cm = float(width_str.rstrip('cm'))
                                table.columns[i].width = Inches(width_cm / 2.54)
                            elif width_str.endswith('in'):
                                width_in = float(width_str.rstrip('in'))
                                table.columns[i].width = Inches(width_in)
                        except ValueError:
                            continue
            
            # 设置边框样式
            if table_format.border_style and table_format.border_style != BorderStyle.NONE:
                DocxProcessor._set_table_borders(table, table_format.border_style, table_format.border_color)
                
        except Exception as e:
            print(f"表格格式化失败: {str(e)}")

    @staticmethod
    def _format_cell(table: Table, cell_id: str, cell_format):
        """
        格式化单元格样式。

        :param table: 表格对象
        :param cell_id: 单元格ID
        :param cell_format: 单元格格式配置
        """
        if not cell_format:
            return
        
        try:
            # 解析单元格ID获取行列索引
            parts = cell_id.split('_')
            if len(parts) >= 3:
                row_col = parts[2]  # 如 "r0c1"
                row_idx = int(row_col.split('c')[0][1:])
                col_idx = int(row_col.split('c')[1])
                
                if 0 <= row_idx < len(table.rows) and 0 <= col_idx < len(table.rows[row_idx].cells):
                    cell = table.rows[row_idx].cells[col_idx]
                    DocxProcessor._apply_cell_formatting(cell, cell_format)
                    
        except (ValueError, IndexError) as e:
            print(f"单元格格式化失败: {str(e)}")

    @staticmethod
    def _modify_cell_content(table: Table, cell_id: str, new_content):
        """
        修改单元格内容。

        :param table: 表格对象
        :param cell_id: 单元格ID
        :param new_content: 新内容
        """
        try:
            # 解析单元格ID获取行列索引
            parts = cell_id.split('_')
            if len(parts) >= 3:
                row_col = parts[2]  # 如 "r0c1"
                row_idx = int(row_col.split('c')[0][1:])
                col_idx = int(row_col.split('c')[1])
                
                if 0 <= row_idx < len(table.rows) and 0 <= col_idx < len(table.rows[row_idx].cells):
                    cell = table.rows[row_idx].cells[col_idx]
                    cell.text = str(new_content)
                    
        except (ValueError, IndexError) as e:
            print(f"单元格内容修改失败: {str(e)}")

    @staticmethod
    def _apply_cell_formatting(cell, cell_format):
        """
        应用单元格格式。

        :param cell: 单元格对象
        :param cell_format: 单元格格式配置
        """
        try:
            # 获取单元格的第一个段落
            if len(cell.paragraphs) > 0:
                paragraph = cell.paragraphs[0]
                
                # 设置对齐方式
                if cell_format.alignment:
                    if cell_format.alignment == CellAlignment.LEFT:
                        paragraph.alignment = WD_PARAGRAPH_ALIGNMENT.LEFT
                    elif cell_format.alignment == CellAlignment.CENTER:
                        paragraph.alignment = WD_PARAGRAPH_ALIGNMENT.CENTER
                    elif cell_format.alignment == CellAlignment.RIGHT:
                        paragraph.alignment = WD_PARAGRAPH_ALIGNMENT.RIGHT
                    elif cell_format.alignment == CellAlignment.JUSTIFY:
                        paragraph.alignment = WD_PARAGRAPH_ALIGNMENT.JUSTIFY
                
                # 设置字体格式
                if len(paragraph.runs) > 0:
                    run = paragraph.runs[0]
                else:
                    run = paragraph.add_run()
                
                if cell_format.bold is not None:
                    run.bold = cell_format.bold
                if cell_format.italic is not None:
                    run.italic = cell_format.italic
                if cell_format.font_size:
                    run.font.size = Pt(cell_format.font_size)
                if cell_format.font_name:
                    run.font.name = cell_format.font_name
                if cell_format.text_color:
                    color_hex = cell_format.text_color.lstrip('#')
                    if len(color_hex) == 6:
                        r = int(color_hex[0:2], 16)
                        g = int(color_hex[2:4], 16)
                        b = int(color_hex[4:6], 16)
                        run.font.color.rgb = RGBColor(r, g, b)
            
            # 设置背景色
            if cell_format.background_color:
                DocxProcessor._set_cell_background_color(cell, cell_format.background_color)
                
        except Exception as e:
            print(f"单元格格式应用失败: {str(e)}")

    @staticmethod
    def _set_cell_background_color(cell, color_hex: str):
        """
        设置单元格背景色。

        :param cell: 单元格对象
        :param color_hex: 十六进制颜色代码
        """
        try:
            color_hex = color_hex.lstrip('#')
            if len(color_hex) == 6:
                # 获取或创建单元格属性
                tc = cell._tc
                tcPr = tc.find(qn('w:tcPr'))
                if tcPr is None:
                    tcPr = OxmlElement('w:tcPr')
                    tc.insert(0, tcPr)
                
                # 设置背景色
                shd = OxmlElement('w:shd')
                shd.set(qn('w:fill'), color_hex.upper())
                tcPr.append(shd)
                
        except Exception as e:
            print(f"设置单元格背景色失败: {str(e)}")

    @staticmethod
    def _set_table_borders(table: Table, border_style: BorderStyle, border_color: str = None):
        """
        设置表格边框。

        :param table: 表格对象
        :param border_style: 边框样式
        :param border_color: 边框颜色
        """
        try:
            # 边框样式映射
            style_map = {
                BorderStyle.SINGLE: 'single',
                BorderStyle.DOUBLE: 'double',
                BorderStyle.THICK: 'thick',
                BorderStyle.THIN: 'single'
            }
            
            border_xml_style = style_map.get(border_style, 'single')
            color = border_color.lstrip('#') if border_color else '000000'
            
            # 创建边框XML
            borders_xml = f'''
            <w:tblBorders {nsdecls("w")}>
                <w:top w:val="{border_xml_style}" w:sz="4" w:space="0" w:color="{color}"/>
                <w:left w:val="{border_xml_style}" w:sz="4" w:space="0" w:color="{color}"/>
                <w:bottom w:val="{border_xml_style}" w:sz="4" w:space="0" w:color="{color}"/>
                <w:right w:val="{border_xml_style}" w:sz="4" w:space="0" w:color="{color}"/>
                <w:insideH w:val="{border_xml_style}" w:sz="4" w:space="0" w:color="{color}"/>
                <w:insideV w:val="{border_xml_style}" w:sz="4" w:space="0" w:color="{color}"/>
            </w:tblBorders>
            '''
            
            # 获取或创建表格属性
            tbl = table._tbl
            tblPr = tbl.find(qn('w:tblPr'))
            if tblPr is None:
                tblPr = OxmlElement('w:tblPr')
                tbl.insert(0, tblPr)
            
            # 移除现有边框设置
            existing_borders = tblPr.find(qn('w:tblBorders'))
            if existing_borders is not None:
                tblPr.remove(existing_borders)
            
            # 添加新边框设置
            borders_element = parse_xml(borders_xml)
            tblPr.append(borders_element)
            
        except Exception as e:
            print(f"设置表格边框失败: {str(e)}") 